<?php
require('class_db.php');

/**
 * Klasa news.
 *
 * Prosta klasa do zarządzania newsami jako przykład idei Automatycznego
 * odświeżania po zmianach w bazie.
 *
 * @author Eliza Witkowska <kokers@codebusters.pl>
 * @link http://blog.codebusters.pl/pl/entry/automatyczne-odswiezanie-po-zmianach-w-bazie
 */
class news {
	/**
	 * Połączenie z bazą
	 *
	 * @var $db;
	 */
	private $db;
	/**
	 * nazwa tabeli newsów w bazie
	 *
	 * @var $table_name = 'news';
	 */
	private $table_name = 'news';

	public $id;
	public $title;
	public $content;
	public $add_date;


	/**
	 * __construct
	 *
	 * @return void
	 */
	function __construct(){
		$this->db = new database();
	}

	/**
	 * Czyszczenie wpisu do bazy.
	 *
	 * @param string $in
	 * @return void
	 */
	function clean($in){
		if(get_magic_quotes_gpc()){
			$in = stripslashes($in);
		}
		return $this->db->escape($in);
	}

	/**
	 * Zarejestruj zmiany.
	 * Funkcja wywoływana po akcjach takich jak edytuj,dodaj,usuń. Zwiększa
	 * licznik w bazie który jest istotny w celu określenie czy nastąpiły jakieś
	 * zmiany w bazie i czy powinna zostać odświeżona lista newsów.
	 * Prawdopodobnie w tabeli przechowywany będzie jakiś identyfikator
	 * użytkownika który dodał news. W związku z tym w pierwszym wierszu w bazie
	 * ta kolumna będzie naszym licznikiem.
	 *
	 * @return void
	 */
	function register_changes(){
		$this->db->query('UPDATE '.$this->table_name.' SET add_user_id = add_user_id + 1 WHERE id=1');
	}

	/**
	 * Sprawdź zmiany.
	 * Pobierz aktualny licznik z bazy.
	 *
	 * @return void
	 */
	function check_changes(){
		$result = $this->db->query('SELECT add_user_id as counting FROM '.$this->table_name.' WHERE id=1 LIMIT 1');
		return $result ? mysqli_fetch_object($result)->counting : FALSE;
	}

	/**
	 * Dodaj news.
	 * Powinniśmy zwiększyć licznik w bazie po poprawnym dodaniu wpisu do bazy
	 * poprzez wywołanie funkcji register_changes().
	 *
	 * @param array $in
	 * @return void
	 */
	function add_news($in=array()){
		$result = $this->db->query('INSERT INTO '.$this->table_name.' ('.implode(',',array_keys($in)).') VALUES ('.implode(',',array_values($in)).')');
		if($this->db->affected_rows()>0){
			$this->register_changes();
			return TRUE;
		}
		return FALSE;
	}

	/**
	 * Edytuj news.
	 * Powinniśmy zwiększyć licznik w bazie po poprawej edycji wpisu w bazie
	 * poprzez wywołanie funkcji register_changes().
	 *
	 * @param array $in
	 * @param int $id
	 * @return void
	 */
	function edit_news($in=array(),$id=0){
		foreach($in as $key => $value) {
			$in_update[]= $key."=".$value."";
		}
		$this->db->query('UPDATE '.$this->table_name.' SET '.implode(", ",$in_update).' WHERE id='.(int)$id);
		if($this->db->affected_rows()>0){
			$this->register_changes();
			return TRUE;
		}
		return FALSE;
	}

	/**
	 * Pobierz newsy.
	 * Pobiera listę newsów..
	 *
	 * @return void
	 */
	function get_news(){
		$result = $this->db->query('SELECT * FROM '.$this->table_name.' WHERE id<>1');
		return $result ? $result : FALSE;
	}
}
/* End of file class_news.php */
